@@ -621,14 +621,6 @@ namespace Tomboy
 			Gtk.LinkButton get_more_link =
 				new Gtk.LinkButton ("http://live.gnome.org/Tomboy/PluginList",
 				                    Catalog.GetString ("Get More Add-Ins..."));
-			get_more_link.Clicked += delegate(object sender, EventArgs args) {
-				string uri = ((Gtk.LinkButton) sender).Uri;
-				try {
-					Services.NativeApplication.OpenUrl (uri, Screen);
-				} catch (Exception e) {
-					GuiUtils.ShowOpeningLocationError (this, uri, e.Message);
-				}
-			};
 			get_more_link.Show ();
 			Gtk.VBox tree_box = new Gtk.VBox (false, 0);
 			tree_box.Add (sw);
@@ -1167,7 +1159,7 @@ namespace Tomboy
 				                                      "You have disabled the configured synchronization service.  " +
 				                                      "Your synchronization settings will now be cleared.  " +
 				                                      "You may be forced to synchronize all of your notes again " +
-				                                      "when you save new settings"));
+				                                      "when you save new settings."));
 				dialog.Run ();
 				dialog.Destroy ();
 			}
